summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmnormaledit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmnormaledit.h')
-rw-r--r--kpovmodeler/pmnormaledit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmnormaledit.h b/kpovmodeler/pmnormaledit.h
index f3fa45b7..1f12a45f 100644
--- a/kpovmodeler/pmnormaledit.h
+++ b/kpovmodeler/pmnormaledit.h
@@ -40,9 +40,9 @@ class PMNormalEdit : public PMTextureBaseEdit
typedef PMTextureBaseEdit Base;
public:
/**
* Creates a PMNormalEdit with tqparent and name
*/
- PMNormalEdit( TQWidget* tqparent, const char* name = 0 );
+ PMNormalEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -40,9 +40,9 @@ class PMNormalEdit : public PMTextureBaseEdit
public:
/**
- * Creates a PMNormalEdit with tqparent and name
+ * Creates a PMNormalEdit with parent and name
*/